PALM-meteo: palmmeteo.utils.Workflow Class Reference

PALM-meteo

Loading...
Searching...
No Matches
Public Member Functions | Public Attributes | List of all members
palmmeteo.utils.Workflow Class Reference

## Public Member Functions
| __init__ (self, default_stages)
| stage_idx (self, s)
| assign_all (self)
| assign_fromto (self, stage_from, stage_to)
| assign_list (self, stages)
| __iter__ (self)

## Public Attributes
| default_stages
| idx
| snapshot_from
| workflow

## Detailed Description

    Indexes and maintains the workflow as a sequence of named stages

## Constructor & Destructor Documentation

## ◆ __init__()

palmmeteo.utils.Workflow.__init__ | ( |  | self,
|  |  | default_stages
| ) |  |

## Member Function Documentation

## ◆ __iter__()

palmmeteo.utils.Workflow.__iter__ | ( |  | self | ) |

## ◆ assign_all()

palmmeteo.utils.Workflow.assign_all | ( |  | self | ) |

## ◆ assign_fromto()

palmmeteo.utils.Workflow.assign_fromto | ( |  | self,
|  |  | stage_from,
|  |  | stage_to
| ) |  |

## ◆ assign_list()

palmmeteo.utils.Workflow.assign_list | ( |  | self,
|  |  | stages
| ) |  |

## ◆ stage_idx()

palmmeteo.utils.Workflow.stage_idx | ( |  | self,
|  |  | s
| ) |  |

## Member Data Documentation

## ◆ default_stages

palmmeteo.utils.Workflow.default_stages

## ◆ idx

palmmeteo.utils.Workflow.idx

## ◆ snapshot_from

palmmeteo.utils.Workflow.snapshot_from

## ◆ workflow

palmmeteo.utils.Workflow.workflow

The documentation for this class was generated from the following file:

- palmmeteo/utils.py